@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2007 Maxime DOYEN
+ *  Copyright (C) 1995-2008 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -302,59 +302,6 @@ struct defoperation_data *data;
 
 }
 
-/*
-**
-*/
-static void defoperation_amountchanged(GtkWidget *widget, gpointer user_data)
-{
-struct defoperation_data *data;
-gint catid, vsign, csign;
-gdouble value;
-Category *cat;
-
-	DB( g_printf("(defoperation) amountchanged\n") );
-
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
-
-	//if a category is selected out there ensure the amount reflect the sign
-	catid = gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_grp));
-
-	if( catid > 0 )
-	{
-		cat = g_list_nth_data(GLOBALS->cat_list, catid);
-		if( cat != NULL )
-		{
-			//get the amount
-			value = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
-
-			vsign = value > 0 ? 1 : -1;
-			csign = cat->flags & GF_INCOME ? 1 : -1;
-
-			DB( g_print("test %d == %d ?\n",vsign,csign) );
-
-
-			if( vsign != csign )
-			{
-				DB( g_print("sould update\n") );				
-
-				value = ABS(value) * csign;
-				
-
-				g_signal_handler_block(data->ST_amount, data->handler_id[HID_AMOUNT]);
-
-				gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), value);
-
-				g_signal_handler_unblock(data->ST_amount, data->handler_id[HID_AMOUNT]);
-
-
-
-			}
-		}
-	}
-
-}
-
 
 /*
 **
@@ -881,12 +828,6 @@ GtkWidget *alignment;
 
 	g_signal_connect (data->CM_valid, "toggled", G_CALLBACK (defoperation_update), NULL);
 
-	//debug
-	data->handler_id[HID_AMOUNT] = g_signal_connect (data->ST_amount, "value-changed", G_CALLBACK (defoperation_amountchanged), NULL);
-	g_signal_connect (data->PO_grp   , "changed"      , G_CALLBACK (defoperation_amountchanged), NULL);
-
-
-
 	//setup, init and show window
 
 	defoperation_setup(data);
