@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2007 Maxime DOYEN
+ *  Copyright (C) 1995-2008 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -76,7 +76,7 @@ struct defpref_data
 
 	//GtkWidget	*NB_numnbdec;
 	//GtkWidget	*CM_numseparator;
-	GtkWidget	*CM_british;
+	GtkWidget	*CM_imperial;
 
 	GtkWidget	*CY_range;
 
@@ -510,7 +510,7 @@ GdkColor color;
 
 	//gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_numnbdec), PREFS->num_nbdecimal);
 	//gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_numseparator), PREFS->num_separator);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_british), PREFS->british_unit);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_imperial), PREFS->imperial_unit);
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_range), PREFS->filter_range);
 
@@ -623,7 +623,7 @@ GdkColor color;
 
 	//PREFS->num_nbdecimal = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_numnbdec));
 	//PREFS->num_separator = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_numseparator));
-	PREFS->british_unit = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_british));
+	PREFS->imperial_unit = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_imperial));
 
 	PREFS->filter_range = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_range));
 
@@ -1028,8 +1028,8 @@ gint row;
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 3, row, row+1);
 
 	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("Use _British units"));
-	data->CM_british = widget;
+	widget = gtk_check_button_new_with_mnemonic (_("Use _Imperial units"));
+	data->CM_imperial = widget;
 	gtk_table_attach (GTK_TABLE (table), widget, 1, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
 
