@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2007 Maxime DOYEN
+ *  Copyright (C) 1995-2008 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -760,7 +760,10 @@ gint result, count;
 				item->flags			= ope->flags  & (OF_INCOME);
 				item->payee			= ope->payee;
 				item->category		= ope->category;
-				item->wording 		= g_strdup(ope->wording);
+				if(ope->wording != NULL)
+					item->wording 		= g_strdup(ope->wording);
+				else
+					item->wording 		= g_strdup(_("(new archive)"));
 
 				GLOBALS->arc_list = g_list_insert_sorted(GLOBALS->arc_list, item, (GCompareFunc)defarchive_list_sort);
 				data->change++;
@@ -934,27 +937,28 @@ GList *list;
 
 				if(ope->flags & OF_VALID)
 					data->bank += ope->amount;
+			}
 
-				/* then filter on date */
-				if(filter_test(data->filter, ope) == 1)
-				{
-					/* append to our treeview */
-					gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+			/* then filter on date */
+			if(filter_test(data->filter, ope) == 1)
+			{
+				/* append to our treeview */
+				gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 
-			 		//g_printf(" populate: %s\n", ope->ope_Word);
+		 		//g_printf(" populate: %s\n", ope->ope_Word);
 
-			 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-						LST_DSPOPE_DATAS, ope,
-						-1);
+		 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+					LST_DSPOPE_DATAS, ope,
+					-1);
 
-				}
-				else
-				{
-					/* later */
-					data->hidden++;
+			}
+			else
+			{
+				/* later */
+				data->hidden++;
 
-				}
-			}		
+			}
+					
 		}
 
 
@@ -1092,7 +1096,7 @@ gboolean result;
 
 				result = gtk_dialog_run (GTK_DIALOG (window));
 
-				if(result != GTK_RESPONSE_REJECT)
+				if(result == GTK_RESPONSE_ADD || result == GTK_RESPONSE_ACCEPT)
 				{
 
 					defoperation_get(window, NULL);
@@ -1527,9 +1531,9 @@ gboolean minor;
 	gtk_statusbar_pop (GTK_STATUSBAR(data->statusbar), 0); /* clear any previous message, underflow is allowed */
 
 	if( count <= 1 )
-		msg = g_strdup_printf ("%d transactions selected, %d hidden", count, data->hidden);
+		msg = g_strdup_printf (_("%d transactions selected, %d hidden"), count, data->hidden);
 	else
-		msg = g_strdup_printf ("%d transactions selected, %d hidden :: %s ( %s - %s)", count, data->hidden, buf3, buf1, buf2);
+		msg = g_strdup_printf (_("%d transactions selected, %d hidden :: %s ( %s - %s)"), count, data->hidden, buf3, buf1, buf2);
 
 	gtk_statusbar_push (GTK_STATUSBAR(data->statusbar), 0, msg);
 	g_free (msg);
