@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2007 Maxime DOYEN
+ *  Copyright (C) 1995-2008 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -679,7 +679,7 @@ static void wallet_about(void)
 		  "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, "
 		  "MA 02110-1301, USA.";
 		  
-	static const gchar *copyright = "Copyright \xc2\xa9 1995-2007 Maxime DOYEN";
+	static const gchar *copyright = "Copyright \xc2\xa9 1995-2008 Maxime DOYEN";
 
 
 	gtk_about_dialog_set_url_hook (activate_url, NULL, NULL);
@@ -881,7 +881,9 @@ gint account, count;
 
 		result = gtk_dialog_run (GTK_DIALOG (window));
 
-		if(result != GTK_RESPONSE_REJECT)
+		DB( g_printf(" -> dialog result is %d\n", result) );
+
+		if(result == GTK_RESPONSE_ADD || result == GTK_RESPONSE_ACCEPT)
 		{
 			defoperation_get(window, NULL);
 			operation_add(ope, NULL, ope->account);
@@ -895,7 +897,6 @@ gint account, count;
 		da_operation_free(ope);
 		ope = NULL;
 
-		DB( g_printf(" -> result %d\n", result) );
 	}
 
 
@@ -1153,6 +1154,7 @@ struct wallet_data *data;
 	}
 }
 
+
 /*
 **
 */
@@ -1529,9 +1531,9 @@ gint flags;
 
 		g_free(data->wintitle);
 		if(!(GLOBALS->change))
-			data->wintitle = g_strdup_printf(PROGNAME " - %s (%s)", GLOBALS->title, basename);
+			data->wintitle = g_strdup_printf("%s (%s) - " PROGNAME, GLOBALS->title, basename);
 		else
-			data->wintitle = g_strdup_printf(PROGNAME " - %s (*%s)", GLOBALS->title, basename);
+			data->wintitle = g_strdup_printf("%s (*%s) - " PROGNAME, GLOBALS->title, basename);
 
 	    gtk_window_set_title (GTK_WINDOW (gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), data->wintitle);
 
@@ -1987,14 +1989,11 @@ wallet_window_screen_changed_cb (GtkWidget *widget,
 			      struct wallet_data *data)
 {
 	GtkWidget *menu_item;
-	GdkScreen *screen;
 
 	DB( g_printf("wallet_window_screen_changed_cb\n") );
 
 
-	screen = gtk_widget_get_screen (widget);	
-
-	data->recent_manager = gtk_recent_manager_get_for_screen (screen);
+	data->recent_manager = gtk_recent_manager_get_default ();
 
 	gtk_menu_detach (GTK_MENU (data->recent_menu));
 	g_object_unref (G_OBJECT (data->recent_menu));
@@ -2204,7 +2203,7 @@ GtkWidget *statusbar;
 	gtk_box_pack_end (GTK_BOX (vbox), statusbar, FALSE, TRUE, 0);
 
 	/* recent files */	
-	data->recent_manager = gtk_recent_manager_get_for_screen (gtk_widget_get_screen (data->window));
+	data->recent_manager = gtk_recent_manager_get_default ();
 
 	data->recent_menu = create_recent_chooser_menu (data->recent_manager);
 
