@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2007 Maxime DOYEN
+ *  Copyright (C) 1995-2008 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -194,7 +194,7 @@ GtkWidget *arrow;
 
 	dateentry->date = g_date_new();
 	/* today's date */
-	g_date_set_time(dateentry->date, time(NULL));
+	g_date_set_time_t(dateentry->date, time(NULL));
 
 	dateentry->entry = gtk_entry_new ();
 	gtk_widget_set_size_request(dateentry->entry, 90, -1);
@@ -310,7 +310,7 @@ void gtk_dateentry_set_date(GtkDateEntry * dateentry, guint julian_days)
 	}
 	else
 	{
-		g_date_set_time(dateentry->date, time(NULL));
+		g_date_set_time_t(dateentry->date, time(NULL));
 	}
 	gtk_dateentry_datetoentry(dateentry);
 }
@@ -441,7 +441,7 @@ const gchar *str;
 	{
 		g_date_free (date);
 		/* today's date */
-		g_date_set_time(dateentry->date, time(NULL));
+		g_date_set_time_t(dateentry->date, time(NULL));
 	}
 
 	gtk_dateentry_datetoentry(dateentry);
