@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2007 Maxime DOYEN
+ *  Copyright (C) 1995-2008 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -687,6 +687,7 @@ gchar *group, *filename;
 			{
 				GLOBALS->filename = g_strdup(g_key_file_get_string  (keyfile, group, "LastOpenedFile", NULL));
 				DB( g_print("lastfile loaded: %s\n", GLOBALS->filename ) );
+				retval = TRUE;
 			}
 		}
 		g_free(filename);
@@ -756,6 +757,8 @@ static void load_list_pixbuf(void)
 {
 guint i;
 
+	DB( g_print("\n(homebank) load_list_pixbuf\n") );
+
     //GLOBALS->lst_pixbuf[LST_PIXBUF_ADD]    = gdk_pixbuf_new_from_file(PIXMAPS_DIR "/lst_new.svg", NULL);
     //GLOBALS->lst_pixbuf[LST_PIXBUF_EDIT]   = gdk_pixbuf_new_from_file(PIXMAPS_DIR "/lst_edit.png", NULL);;
     //GLOBALS->lst_pixbuf[LST_PIXBUF_REMIND] = gdk_pixbuf_new_from_file(PIXMAPS_DIR "/lst_remind.png", NULL);
@@ -786,7 +789,7 @@ guint i;
 
 	}
 
-	DB( g_print("pixbuf list maxwidth: %d\n", GLOBALS->lst_pixbuf_maxwidth) );
+	DB( g_print(" -> pixbuf list maxwidth: %d\n", GLOBALS->lst_pixbuf_maxwidth) );
 
 }
 
@@ -860,8 +863,6 @@ static void homebank_cleanup()
 	//v3.4 save windows size/position
 	homebank_pref_save();
 
-	homebank_lastopenedfiles_save();
-
 	free_list_pixbuf();
 	free_paymode_icons();
 	free_pref_icons();
@@ -933,7 +934,7 @@ GDate *date;
 
 	/* today's date */
 	date = g_date_new();
-	g_date_set_time(date, time(NULL));
+	g_date_set_time_t(date, time(NULL));
 	GLOBALS->today = g_date_get_julian(date);
 	g_date_free(date);
 
@@ -1078,7 +1079,7 @@ gboolean openlast;
 	}
 
 	/* Pass NULL here since we parsed the gtk+ args already...
-	 * from this point on we need a DISPLAY variable to be set.
+	 * from this point all we need a DISPLAY variable to be set.
 	 */
 	gtk_init (NULL, NULL);
 
@@ -1097,12 +1098,13 @@ gboolean openlast;
 
 	if( homebank_setup() )
 	{
-		DB( g_print("** creating window\n" ) );
 
 		pathfilename = g_build_filename(homebank_pixmaps_dir, "homebank.svg", NULL);
 		gtk_window_set_default_icon_from_file(pathfilename, NULL);
 		g_free(pathfilename);
 
+		DB( g_print(" -> creating window\n" ) );
+
 		mainwin = (GtkWidget *)create_wallet_window (NULL);
 
 		if(mainwin)
@@ -1124,6 +1126,8 @@ gboolean openlast;
 				gtk_main_iteration ();
 
 
+			DB( g_print(" -> open last file ?\n" ) );
+
 			// load a file ?
 			/* load 1st file specified on commandline */
 			openlast = TRUE;
@@ -1131,7 +1135,7 @@ gboolean openlast;
 			{
 				if (g_file_test (files[0], G_FILE_TEST_EXISTS) != FALSE)
 				{
-					DB( g_print(" - should load %s\n", files[0] ) );
+					DB( g_print(" -> should load %s\n", files[0] ) );
 					g_free(GLOBALS->filename);
 					GLOBALS->filename = g_strdup(files[0]);
 					wallet_open_internal(mainwin, NULL);
@@ -1146,12 +1150,12 @@ gboolean openlast;
 			}
 			
 			
-			DB( g_print("GLOBALS->filename: '%s'\n", GLOBALS->filename ) );
+			DB( g_print(" -> GLOBALS->filename: '%s'\n", GLOBALS->filename ) );
 			
 			if( openlast )
 			{
-				homebank_lastopenedfiles_load();
-				wallet_open_internal(mainwin, NULL);
+				if( homebank_lastopenedfiles_load() == TRUE )
+					wallet_open_internal(mainwin, NULL);
 			}
 
 			/* update the mainwin display */
