@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2007 Maxime DOYEN
+ *  Copyright (C) 1995-2008 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -22,7 +22,8 @@
 
 #include <config.h>
 
-#include <glib-2.0/glib.h>
+#include <glib.h>
+#include <glib/gprintf.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
 
