@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2007 Maxime DOYEN
+ *  Copyright (C) 1995-2008 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -461,7 +461,7 @@ GError *error = NULL;
 					homebank_pref_get_short(keyfile, group, "FracDigits", &PREFS->base_cur.frac_digits);
 				}
 
-				homebank_pref_get_boolean(keyfile, group, "UKUnits", &PREFS->british_unit);
+				homebank_pref_get_boolean(keyfile, group, "UKUnits", &PREFS->imperial_unit);
 				
 
 			group = "Filter";
@@ -586,7 +586,7 @@ guint length;
 		g_key_file_set_string  (keyfile, group, "GroupChar" , PREFS->base_cur.grouping_char);
 		g_key_file_set_integer (keyfile, group, "FracDigits", PREFS->base_cur.frac_digits);
 
-		g_key_file_set_boolean (keyfile, group, "UKUnits" , PREFS->british_unit);
+		g_key_file_set_boolean (keyfile, group, "UKUnits" , PREFS->imperial_unit);
 
 		group = "Filter";
 		g_key_file_set_integer (keyfile, group, "DefRange", PREFS->filter_range);
