@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2007 Maxime DOYEN
+ *  Copyright (C) 1995-2008 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -89,7 +89,7 @@ struct Preferences
 
 	//gshort	num_nbdecimal;
 	//gboolean	num_separator;
-	gboolean	british_unit;
+	gboolean	imperial_unit;
 
 	//help system
 	//gboolean	show_tooltips;
