@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2007 Maxime DOYEN
+ *  Copyright (C) 1995-2008 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -674,6 +674,7 @@ GList *list;
 gint n_result, i, id;
 GDate *date1, *date2;
 gdouble *tmp_income, *tmp_expense;
+gdouble exprate, incrate, balrate;
 
 	DB( g_print("(statistic) compute\n") );
 
@@ -859,6 +860,20 @@ gdouble *tmp_income, *tmp_expense;
 
 			DB( g_print(" inserting %2d, %48s, %9.2f %9.2f %9.2f\n", i, name, tmp_expense[i], tmp_income[i], tmp_expense[i] + tmp_income[i]) );
 
+			//compute rate
+			exprate = 0.0;
+			incrate = 0.0;
+			balrate = 0.0;
+
+			if( data->total_expense )
+				exprate = (ABS(tmp_expense[i]) * 100 / data->total_expense);
+			
+			if( data->total_income )
+				incrate = (tmp_income[i] * 100 / data->total_income);
+				
+			if( (data->total_expense + data->total_income) )
+				balrate = (ABS(tmp_expense[i]) + tmp_income[i]) * 100 / (data->total_expense + data->total_income);
+
 	    	gtk_list_store_append (GTK_LIST_STORE(model), &iter);
      		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
 				LST_STAT_POS, id++,
@@ -867,9 +882,9 @@ gdouble *tmp_income, *tmp_expense;
 				LST_STAT_EXPENSE, tmp_expense[i],
 				LST_STAT_INCOME, tmp_income[i],
 				LST_STAT_BALANCE, tmp_expense[i] + tmp_income[i],
-				LST_STAT_EXPRATE, (ABS(tmp_expense[i]) * 100 / data->total_expense),
-				LST_STAT_INCRATE, (tmp_income[i] * 100 / data->total_income),
-				LST_STAT_BALRATE, (ABS(tmp_expense[i]) + tmp_income[i]) * 100 / (data->total_expense + data->total_income) ,
+				LST_STAT_EXPRATE, exprate,
+				LST_STAT_INCRATE, incrate,
+				LST_STAT_BALRATE, balrate,
 				-1);
 
 			g_free(fullcatname);
